@@ -2,8 +2,8 @@
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: dns
 version: 2.0.2
-id: dns-2.0.2-5e4d4e169145c1621c42b290ae390f49
-key: dns_ENFhUugr5jI93Dy7QF38Rf
+id: dns-2.0.2-ac237de79a0ae5f78508e767a0b30196
+key: dns_6914X25iTja2Dj3MmxOUhN
 license: BSD3
 maintainer: Kazu Yamamoto <kazu@iij.ad.jp>
 synopsis: DNS library in Haskell
@@ -22,15 +22,15 @@ trusted: False
 import-dirs: /usr/lib/ghc-7.10.3/site-local/dns-2.0.2
 library-dirs: /usr/lib/ghc-7.10.3/site-local/dns-2.0.2
 data-dir: /usr/share/arm-linux-ghc-7.10.3/dns-2.0.2
-hs-libraries: HSdns-2.0.2-ENFhUugr5jI93Dy7QF38Rf
+hs-libraries: HSdns-2.0.2-6914X25iTja2Dj3MmxOUhN
 depends:
-    attoparsec-0.13.0.1-522c252ad233781393fab28c8daf023a
+    attoparsec-0.13.0.2-669cbb29a91e49834657a781d3adc2de
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
     binary-0.7.5.0-29f7044fa0b12dc5c2dcec897db5c464
-    blaze-builder-0.4.0.1-0c3e4ae1ea19a65d81d24f4a911c903b
+    blaze-builder-0.4.0.2-290873936811c5be5456133d1e8642df
     bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
     conduit-1.2.6.4-9cbf21b79aba616188d311eceb1fecef
-    conduit-extra-1.1.13.1-49d5b7e57d33a6d70b83744864ccf557
+    conduit-extra-1.1.13.1-b0a6afe4d52c8bc50dff37cca54ee4a6
     containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
     iproute-1.7.0-38a0b7111fde75b34af10d9c12292092
     mtl-2.2.1-c516313407bc17046965067cb7cbb6a0
